@@ -7,6 +7,7 @@ mod bold_cs;
 mod bookmark_end;
 mod bookmark_start;
 mod br;
+mod character_spacing;
 mod color;
 mod comment;
 mod comment_extended;
@@ -36,6 +37,7 @@ mod level_jc;
 mod level_override;
 mod level_restart;
 mod level_text;
+mod line_spacing;
 mod mc_fallback;
 mod name;
 mod next;
@@ -58,7 +60,6 @@ mod run_property_default;
 mod section;
 mod section_property;
 mod shading;
-mod spacing;
 mod start;
 mod style;
 mod sz;
@@ -102,6 +103,7 @@ pub use bold_cs::*;
 pub use bookmark_end::*;
 pub use bookmark_start::*;
 pub use br::*;
+pub use character_spacing::*;
 pub use color::*;
 pub use comment::*;
 pub use comment_extended::*;
@@ -131,6 +133,7 @@ pub use level_jc::*;
 pub use level_override::*;
 pub use level_restart::*;
 pub use level_text::*;
+pub use line_spacing::*;
 pub use mc_fallback::*;
 pub use name::*;
 pub use next::*;
@@ -153,7 +156,6 @@ pub use run_property_default::*;
 pub use section::*;
 pub use section_property::*;
 pub use shading::*;
-pub use spacing::*;
 pub use start::*;
 pub use style::*;
 pub use sz::*;
