@@ -142,7 +142,7 @@ impl Run {
         self
     }
 
-    pub fn spacing(mut self, v: i32) -> Run {
+    pub fn character_spacing(mut self, v: i32) -> Run {
         self.run_property = self.run_property.spacing(v);
         self
     }
@@ -277,13 +277,13 @@ mod tests {
                 italic: Some(Italic::new()),
                 italic_cs: Some(ItalicCs::new()),
                 vanish: Some(Vanish::new()),
-                spacing: Some(100),
+                character_spacing: Some(CharacterSpacing::new(100)),
                 ..RunProperty::default()
             },
         };
         assert_eq!(
             serde_json::to_string(&run).unwrap(),
-            r#"{"runProperty":{"sz":30,"szCs":30,"color":"C9211E","highlight":"yellow","vertAlign":null,"underline":"single","bold":true,"boldCs":true,"italic":true,"italicCs":true,"vanish":true,"spacing":100,"fonts":null,"textBorder":null,"del":null,"ins":null},"children":[{"type":"tab"},{"type":"text","data":{"preserveSpace":true,"text":"Hello"}},{"type":"break","data":{"breakType":"page"}},{"type":"deleteText","data":{"text":"deleted","preserveSpace":true}}]}"#,
+            r#"{"runProperty":{"sz":30,"szCs":30,"color":"C9211E","highlight":"yellow","vertAlign":null,"underline":"single","bold":true,"boldCs":true,"italic":true,"italicCs":true,"vanish":true,"characterSpacing":100,"fonts":null,"textBorder":null,"del":null,"ins":null},"children":[{"type":"tab"},{"type":"text","data":{"preserveSpace":true,"text":"Hello"}},{"type":"break","data":{"breakType":"page"}},{"type":"deleteText","data":{"text":"deleted","preserveSpace":true}}]}"#,
         );
     }
 }
