@@ -8,11 +8,11 @@ pub mod errors;
 pub mod font_pitch_type;
 pub mod height_rule;
 pub mod level_suffix_type;
+pub mod line_spacing_type;
 pub mod page_margin;
 pub mod page_orientation_type;
 pub mod section_type;
 pub mod shd_type;
-pub mod spacing;
 pub mod special_indent_type;
 pub mod style_type;
 pub mod table_alignment_type;
@@ -33,11 +33,11 @@ pub use errors::*;
 pub use font_pitch_type::*;
 pub use height_rule::*;
 pub use level_suffix_type::*;
+pub use line_spacing_type::*;
 pub use page_margin::*;
 pub use page_orientation_type::*;
 pub use section_type::*;
 pub use shd_type::*;
-pub use spacing::*;
 pub use special_indent_type::*;
 pub use style_type::*;
 pub use table_alignment_type::*;
